@@ -375,6 +375,45 @@ class ClusterType(AsyncType[str]):
 CLUSTER = ClusterType()
 
 
+class OrgType(AsyncType[str]):
+    name = "org"
+    NO_ORG_STR = "NO_ORG"
+
+    async def async_convert(
+        self,
+        root: Root,
+        value: str,
+        param: Optional[click.Parameter],
+        ctx: Optional[click.Context],
+    ) -> str:
+        client = await root.init_client()
+        org_name = value if value != self.NO_ORG_STR else None
+        if org_name not in client.config.clusters[client.config.cluster_name].orgs:
+            raise click.BadParameter(
+                f"Org {value} is not valid, "
+                "run 'neuro config get-clusters' to get a list of available orgs",
+                ctx,
+                param,
+            )
+        return value
+
+    async def async_shell_complete(
+        self, root: Root, ctx: click.Context, param: click.Parameter, incomplete: str
+    ) -> List[CompletionItem]:
+        # async context manager is used to prevent a message about
+        # unclosed session
+        async with await root.init_client() as client:
+            org_names = [org or self.NO_ORG_STR for org in client.config.cluster_orgs]
+            return [
+                CompletionItem(org_name)
+                for org_name in org_names
+                if org_name.startswith(incomplete)
+            ]
+
+
+ORG = OrgType()
+
+
 class JobType(AsyncType[str]):
     name = "job"
 
@@ -603,10 +642,9 @@ class BlobPathURLCompleter(PathURLCompleter):
     async def _iter_dir(
         self, root: Root, uri: URL
     ) -> AsyncIterator[PathURLCompleter.DirEntry]:
-        res = root.client.parse.split_blob_uri(uri)
         async with root.client.buckets.list_blobs(uri) as it:
             async for blob_entry in it:
-                if blob_entry.key == res.key:
+                if blob_entry.uri == uri:
                     continue  # Directory itself is also listed as it is prefix search
                 yield blob_entry
 
