@@ -9,6 +9,7 @@ from rich.text import Text
 
 from neuro_sdk import Bucket
 
+from neuro_cli.click_types import ORG
 from neuro_cli.formatters.utils import DatetimeFormatter, URIFormatter
 
 
@@ -44,6 +45,7 @@ class BucketsFormatter(BaseBucketsFormatter):
         ]
         if self._long_format:
             line += [
+                bucket.org_name or ORG.NO_ORG_STR,
                 self._datetime_formatter(bucket.created_at),
                 "√" if bucket.public else "×",
             ]
@@ -59,6 +61,7 @@ class BucketsFormatter(BaseBucketsFormatter):
         table.add_column("Provider")
         table.add_column("Uri")
         if self._long_format:
+            table.add_column("Org name")
             table.add_column("Created at")
             table.add_column("Public")
         for bucket in buckets:
@@ -85,6 +88,7 @@ class BucketFormatter:
         table.add_row("Uri", self._uri_formatter(bucket.uri))
         if bucket.name:
             table.add_row("Name", bucket.name)
+        table.add_row("Org name", bucket.org_name or ORG.NO_ORG_STR)
         table.add_row("Created at", self._datetime_formatter(bucket.created_at))
         table.add_row("Provider", bucket.provider)
         table.add_row("Imported", str(bucket.imported))
